# button.py
# Vietnamese-German Univerity
# By Richard Bradley
# Program to shutdown the system when the button is pushed
# based on the sample program button.py
# created by  Emutex Ltd.
# http://www.emutex.com
# Connections: 
#    LED connected to pin 8(with 300R resistor)
#    Button connected to pin 7, input is pulled to ground via 10k resistor and when pressed goes high to 5V
############################################
#        Import Libraries                  #
############################################
# Import the GPIOGalileo class from the wiringx86 module.
from wiringx86 import GPIOGalileo as GPIO
import os # allows use of os commands
import time # import so can use sleep function
###########################################
#       Global Variables                  #
###########################################
# Create a new instance of the GPIOGalileo class.
# Setting debug=True gives information about the interaction with sysfs.
gpio = GPIO(debug=False)
LED = 8
button = 7
##########################################
#                Main                    #
##########################################
# Set LED to be used as an output GPIO pin.
gpio.pinMode(LED, gpio.OUTPUT)

# Set button  to be used as an input GPIO pin.
gpio.pinMode(button, gpio.INPUT)

# Flash LED 3 times
gpio.digitalWrite(LED, gpio.HIGH)
time.sleep(1) # sleep for 1 second
gpio.digitalWrite(LED, gpio.LOW)
time.sleep(1) # sleep for 1 second
gpio.digitalWrite(LED, gpio.HIGH)
time.sleep(1) # sleep for 1 second
gpio.digitalWrite(LED, gpio.LOW)
time.sleep(1) # sleep for 1 second
gpio.digitalWrite(LED, gpio.HIGH)
time.sleep(1) # sleep for 1 second
gpio.digitalWrite(LED, gpio.LOW)
time.sleep(1) # sleep for 1 second

# Check button for status and if on, turn on LED and shutdown
try:
    while(True):
        # Read the state of the button
        state = gpio.digitalRead(button)

        # If the button is pressed turn ON LED
        if state == 1:
            gpio.digitalWrite(LED, gpio.HIGH)
           # print "System is going down"
            os.system("shutdown -h now")
            time.sleep(30) # sleep for 30 seconds

        # If the button is not pressed turn OFF LED
        else:
            gpio.digitalWrite(LED, gpio.LOW)

# Kill the loop with Ctrl-C.
except KeyboardInterrupt:
    # Leave the led turned off.
#    print '\nCleaning up...'
    gpio.digitalWrite(LED, gpio.LOW)

    # Do a general cleanup. Calling this function is not mandatory.
    gpio.cleanup()
